pub type IAccessibleWinSAT = *mut ::core::ffi::c_void;
pub type IInitiateWinSATAssessment = *mut ::core::ffi::c_void;
pub type IProvideWinSATAssessmentInfo = *mut ::core::ffi::c_void;
pub type IProvideWinSATResultsInfo = *mut ::core::ffi::c_void;
pub type IProvideWinSATVisuals = *mut ::core::ffi::c_void;
pub type IQueryAllWinSATAssessments = *mut ::core::ffi::c_void;
pub type IQueryOEMWinSATCustomization = *mut ::core::ffi::c_void;
pub type IQueryRecentWinSATAssessment = *mut ::core::ffi::c_void;
pub type IWinSATInitiateEvents = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CAccessiblityWinSAT: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x6e18f9c6_a3eb_495a_89b7_956482e19f7a);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CInitiateWinSAT: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x489331dc_f5e0_4528_9fda_45331bf4a571);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CProvideWinSATVisuals: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x9f377d7e_e551_44f8_9f94_9db392b03b7b);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CQueryAllWinSAT: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x05df8d13_c355_47f4_a11e_851b338cefb8);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CQueryOEMWinSATCustomization: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xc47a41b7_b729_424f_9af9_5cb3934f2dfa);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const CQueryWinSAT: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xf3bdfad3_f276_49e9_9b17_c474f48f0764);
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub type WINSAT_ASSESSMENT_STATE = i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_MIN: WINSAT_ASSESSMENT_STATE = 0i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_UNKNOWN: WINSAT_ASSESSMENT_STATE = 0i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_VALID: WINSAT_ASSESSMENT_STATE = 1i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_INCOHERENT_WITH_HARDWARE: WINSAT_ASSESSMENT_STATE = 2i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_NOT_AVAILABLE: WINSAT_ASSESSMENT_STATE = 3i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_INVALID: WINSAT_ASSESSMENT_STATE = 4i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_STATE_MAX: WINSAT_ASSESSMENT_STATE = 4i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub type WINSAT_ASSESSMENT_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_MEMORY: WINSAT_ASSESSMENT_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_CPU: WINSAT_ASSESSMENT_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_DISK: WINSAT_ASSESSMENT_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_D3D: WINSAT_ASSESSMENT_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_ASSESSMENT_GRAPHICS: WINSAT_ASSESSMENT_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub type WINSAT_BITMAP_SIZE = i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_BITMAP_SIZE_SMALL: WINSAT_BITMAP_SIZE = 0i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_BITMAP_SIZE_NORMAL: WINSAT_BITMAP_SIZE = 1i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub type WINSAT_OEM_CUSTOMIZATION_STATE = i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_OEM_DATA_VALID: WINSAT_OEM_CUSTOMIZATION_STATE = 0i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_OEM_DATA_NON_SYS_CONFIG_MATCH: WINSAT_OEM_CUSTOMIZATION_STATE = 1i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_OEM_DATA_INVALID: WINSAT_OEM_CUSTOMIZATION_STATE = 2i32;
#[doc = "*Required features: `\"Win32_System_AssessmentTool\"`*"]
pub const WINSAT_OEM_NO_DATA_SUPPLIED: WINSAT_OEM_CUSTOMIZATION_STATE = 3i32;
