pub type AppEvents = *mut ::core::ffi::c_void;
pub type Column = *mut ::core::ffi::c_void;
pub type Columns = *mut ::core::ffi::c_void;
pub type ContextMenu = *mut ::core::ffi::c_void;
pub type Document = *mut ::core::ffi::c_void;
pub type Extension = *mut ::core::ffi::c_void;
pub type Extensions = *mut ::core::ffi::c_void;
pub type Frame = *mut ::core::ffi::c_void;
pub type IColumnData = *mut ::core::ffi::c_void;
pub type IComponent = *mut ::core::ffi::c_void;
pub type IComponent2 = *mut ::core::ffi::c_void;
pub type IComponentData = *mut ::core::ffi::c_void;
pub type IComponentData2 = *mut ::core::ffi::c_void;
pub type IConsole = *mut ::core::ffi::c_void;
pub type IConsole2 = *mut ::core::ffi::c_void;
pub type IConsole3 = *mut ::core::ffi::c_void;
pub type IConsoleNameSpace = *mut ::core::ffi::c_void;
pub type IConsoleNameSpace2 = *mut ::core::ffi::c_void;
pub type IConsolePower = *mut ::core::ffi::c_void;
pub type IConsolePowerSink = *mut ::core::ffi::c_void;
pub type IConsoleVerb = *mut ::core::ffi::c_void;
pub type IContextMenuCallback = *mut ::core::ffi::c_void;
pub type IContextMenuCallback2 = *mut ::core::ffi::c_void;
pub type IContextMenuProvider = *mut ::core::ffi::c_void;
pub type IControlbar = *mut ::core::ffi::c_void;
pub type IDisplayHelp = *mut ::core::ffi::c_void;
pub type IEnumTASK = *mut ::core::ffi::c_void;
pub type IExtendContextMenu = *mut ::core::ffi::c_void;
pub type IExtendControlbar = *mut ::core::ffi::c_void;
pub type IExtendPropertySheet = *mut ::core::ffi::c_void;
pub type IExtendPropertySheet2 = *mut ::core::ffi::c_void;
pub type IExtendTaskPad = *mut ::core::ffi::c_void;
pub type IExtendView = *mut ::core::ffi::c_void;
pub type IHeaderCtrl = *mut ::core::ffi::c_void;
pub type IHeaderCtrl2 = *mut ::core::ffi::c_void;
pub type IImageList = *mut ::core::ffi::c_void;
pub type IMMCVersionInfo = *mut ::core::ffi::c_void;
pub type IMenuButton = *mut ::core::ffi::c_void;
pub type IMessageView = *mut ::core::ffi::c_void;
pub type INodeProperties = *mut ::core::ffi::c_void;
pub type IPropertySheetCallback = *mut ::core::ffi::c_void;
pub type IPropertySheetProvider = *mut ::core::ffi::c_void;
pub type IRequiredExtensions = *mut ::core::ffi::c_void;
pub type IResultData = *mut ::core::ffi::c_void;
pub type IResultData2 = *mut ::core::ffi::c_void;
pub type IResultDataCompare = *mut ::core::ffi::c_void;
pub type IResultDataCompareEx = *mut ::core::ffi::c_void;
pub type IResultOwnerData = *mut ::core::ffi::c_void;
pub type ISnapinAbout = *mut ::core::ffi::c_void;
pub type ISnapinHelp = *mut ::core::ffi::c_void;
pub type ISnapinHelp2 = *mut ::core::ffi::c_void;
pub type ISnapinProperties = *mut ::core::ffi::c_void;
pub type ISnapinPropertiesCallback = *mut ::core::ffi::c_void;
pub type IStringTable = *mut ::core::ffi::c_void;
pub type IToolbar = *mut ::core::ffi::c_void;
pub type IViewExtensionCallback = *mut ::core::ffi::c_void;
pub type MenuItem = *mut ::core::ffi::c_void;
pub type Node = *mut ::core::ffi::c_void;
pub type Nodes = *mut ::core::ffi::c_void;
pub type Properties = *mut ::core::ffi::c_void;
pub type Property = *mut ::core::ffi::c_void;
pub type ScopeNamespace = *mut ::core::ffi::c_void;
pub type SnapIn = *mut ::core::ffi::c_void;
pub type SnapIns = *mut ::core::ffi::c_void;
pub type View = *mut ::core::ffi::c_void;
pub type Views = *mut ::core::ffi::c_void;
pub type _AppEvents = *mut ::core::ffi::c_void;
pub type _Application = *mut ::core::ffi::c_void;
pub type _EventConnector = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const AUTO_WIDTH: i32 = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const AppEventsDHTMLConnector: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xade6444b_c91f_4e37_92a4_5bb430a33340);
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Application: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x49b2791a_b1ae_4c90_9b8e_e860ba07f889);
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ConsolePower: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xf0285374_dff1_11d3_b433_00c04f8ecd78);
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const HDI_HIDDEN: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const HIDE_COLUMN: i32 = -4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ILSIF_LEAVE_LARGE_ICON: u32 = 1073741824u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ILSIF_LEAVE_SMALL_ICON: u32 = 536870912u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_AUTO: i32 = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_NOICON: i32 = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_NOPARAM: i32 = -2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_NOPTR: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_UPDATE_NOINVALIDATEALL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_UPDATE_NOSCROLL: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_VIEWSTYLE_FILTERED: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_VIEWSTYLE_ICON: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_VIEWSTYLE_LIST: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_VIEWSTYLE_REPORT: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCLV_VIEWSTYLE_SMALLICON: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCVersionInfo: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xd6fedb1d_cf21_4bd9_af3b_c5468e9c6684);
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_DEFAULT_OPERATION_COPY: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_IMAGECALLBACK: i32 = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ITEM_OVERLAY_STATE_MASK: u32 = 3840u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ITEM_OVERLAY_STATE_SHIFT: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ITEM_STATE_MASK: u32 = 255u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_MULTI_SELECT_COOKIE: i32 = -2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NODEID_SLOW_RETRIEVAL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_CUSTOMTITLE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_NOACTIONPANE: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_NOPERSIST: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_NOSCOPEPANE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_NOTOOLBARS: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NW_OPTION_SHORTTITLE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROP_CHANGEAFFECTSUI: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROP_MODIFIABLE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROP_PERSIST: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROP_REMOVABLE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PSO_HASHELP: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PSO_NEWWIZARDTYPE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PSO_NOAPPLYNOW: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PSO_NO_PROPTITLE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VER: u32 = 512u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_CREATENEW: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_EXCLUDE_SCOPE_ITEMS_FROM_LIST: u32 = 64u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_FILTERED: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_LEXICAL_SORT: u32 = 128u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_MULTISELECT: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_NOLISTVIEWS: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_OWNERDATALIST: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_OPTIONS_USEFONTLINKING: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_WINDOW_COOKIE: i32 = -3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDCI_ScopeItem: u32 = 2147483648u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_IMAGE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_INDENT: u32 = 64u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_INDEX: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_PARAM: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_STATE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RDI_STR: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RFI_PARTIAL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RFI_WRAP: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RSI_DESCENDING: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RSI_NOSORTICON: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_HTML_OPTIONS_NOLISTVIEW: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_HTML_OPTIONS_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_ALLOWPASTE: u32 = 256u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_EXCLUDE_SCOPE_ITEMS_FROM_LIST: u32 = 64u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_FILTERED: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_LEXICAL_SORT: u32 = 128u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_MULTISELECT: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_OWNERDATALIST: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_LIST_OPTIONS_USEFONTLINKING: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_MISC_OPTIONS_NOLISTVIEWS: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_OCX_OPTIONS_CACHE_OCX: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_OCX_OPTIONS_NOLISTVIEW: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const RVTI_OCX_OPTIONS_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_CHILDREN: u32 = 64u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_FIRST: u32 = 134217728u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_IMAGE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_NEXT: u32 = 536870912u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_OPENIMAGE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_PARAM: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_PARENT: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_PREVIOUS: u32 = 268435456u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_STATE: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SDI_STR: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SPECIAL_COOKIE_MAX: i32 = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SPECIAL_COOKIE_MIN: i32 = -10i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SPECIAL_DOBJ_MAX: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SPECIAL_DOBJ_MIN: i32 = -10i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type CCM_COMMANDID_MASK_CONSTANTS = u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_COMMANDID_MASK_RESERVED: CCM_COMMANDID_MASK_CONSTANTS = 4294901760u32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type CCM_INSERTIONALLOWED = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONALLOWED_TOP: CCM_INSERTIONALLOWED = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONALLOWED_NEW: CCM_INSERTIONALLOWED = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONALLOWED_TASK: CCM_INSERTIONALLOWED = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONALLOWED_VIEW: CCM_INSERTIONALLOWED = 8i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type CCM_INSERTIONPOINTID = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_SPECIAL: CCM_INSERTIONPOINTID = -65536i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_SHARED: CCM_INSERTIONPOINTID = -2147483648i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_CREATE_PRIMARY: CCM_INSERTIONPOINTID = 1073741824i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_ADD_PRIMARY: CCM_INSERTIONPOINTID = 536870912i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_ADD_3RDPARTY: CCM_INSERTIONPOINTID = 268435456i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_RESERVED: CCM_INSERTIONPOINTID = 268369920i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_MASK_FLAGINDEX: CCM_INSERTIONPOINTID = 31i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_PRIMARY_TOP: CCM_INSERTIONPOINTID = -1610612736i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_PRIMARY_NEW: CCM_INSERTIONPOINTID = -1610612735i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_PRIMARY_TASK: CCM_INSERTIONPOINTID = -1610612734i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_PRIMARY_VIEW: CCM_INSERTIONPOINTID = -1610612733i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_PRIMARY_HELP: CCM_INSERTIONPOINTID = -1610612732i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_3RDPARTY_NEW: CCM_INSERTIONPOINTID = -1879048191i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_3RDPARTY_TASK: CCM_INSERTIONPOINTID = -1879048190i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_INSERTIONPOINTID_ROOT_MENU: CCM_INSERTIONPOINTID = -2147483648i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type CCM_SPECIAL = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_SPECIAL_SEPARATOR: CCM_SPECIAL = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_SPECIAL_SUBMENU: CCM_SPECIAL = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_SPECIAL_DEFAULT_ITEM: CCM_SPECIAL = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_SPECIAL_INSERTION_POINT: CCM_SPECIAL = 8i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCM_SPECIAL_TESTONLY: CCM_SPECIAL = 16i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type DATA_OBJECT_TYPES = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCT_SCOPE: DATA_OBJECT_TYPES = 32768i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCT_RESULT: DATA_OBJECT_TYPES = 32769i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCT_SNAPIN_MANAGER: DATA_OBJECT_TYPES = 32770i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CCT_UNINITIALIZED: DATA_OBJECT_TYPES = 65535i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type IconIdentifier = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_None: IconIdentifier = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_Error: IconIdentifier = 32513i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_Question: IconIdentifier = 32514i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_Warning: IconIdentifier = 32515i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_Information: IconIdentifier = 32516i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_First: IconIdentifier = 32513i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const Icon_Last: IconIdentifier = 32516i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_ACTION_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ACTION_UNINITIALIZED: MMC_ACTION_TYPE = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ACTION_ID: MMC_ACTION_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ACTION_LINK: MMC_ACTION_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ACTION_SCRIPT: MMC_ACTION_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_BUTTON_STATE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ENABLED: MMC_BUTTON_STATE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const CHECKED: MMC_BUTTON_STATE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const HIDDEN: MMC_BUTTON_STATE = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const INDETERMINATE: MMC_BUTTON_STATE = 8i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const BUTTONPRESSED: MMC_BUTTON_STATE = 16i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_CONSOLE_VERB = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_NONE: MMC_CONSOLE_VERB = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_OPEN: MMC_CONSOLE_VERB = 32768i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_COPY: MMC_CONSOLE_VERB = 32769i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_PASTE: MMC_CONSOLE_VERB = 32770i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_DELETE: MMC_CONSOLE_VERB = 32771i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_PROPERTIES: MMC_CONSOLE_VERB = 32772i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_RENAME: MMC_CONSOLE_VERB = 32773i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_REFRESH: MMC_CONSOLE_VERB = 32774i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_PRINT: MMC_CONSOLE_VERB = 32775i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_CUT: MMC_CONSOLE_VERB = 32776i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_MAX: MMC_CONSOLE_VERB = 32777i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_FIRST: MMC_CONSOLE_VERB = 32768i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VERB_LAST: MMC_CONSOLE_VERB = 32776i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_CONTROL_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const TOOLBAR: MMC_CONTROL_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MENUBUTTON: MMC_CONTROL_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const COMBOBOXBAR: MMC_CONTROL_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_FILTER_CHANGE_CODE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MFCC_DISABLE: MMC_FILTER_CHANGE_CODE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MFCC_ENABLE: MMC_FILTER_CHANGE_CODE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MFCC_VALUE_CHANGE: MMC_FILTER_CHANGE_CODE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_FILTER_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_STRING_FILTER: MMC_FILTER_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_INT_FILTER: MMC_FILTER_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_FILTER_NOVALUE: MMC_FILTER_TYPE = 32768i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_MENU_COMMAND_IDS = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCC_STANDARD_VIEW_SELECT: MMC_MENU_COMMAND_IDS = -1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_NOTIFY_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_ACTIVATE: MMC_NOTIFY_TYPE = 32769i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_ADD_IMAGES: MMC_NOTIFY_TYPE = 32770i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_BTN_CLICK: MMC_NOTIFY_TYPE = 32771i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_CLICK: MMC_NOTIFY_TYPE = 32772i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_COLUMN_CLICK: MMC_NOTIFY_TYPE = 32773i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_CONTEXTMENU: MMC_NOTIFY_TYPE = 32774i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_CUTORMOVE: MMC_NOTIFY_TYPE = 32775i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_DBLCLICK: MMC_NOTIFY_TYPE = 32776i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_DELETE: MMC_NOTIFY_TYPE = 32777i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_DESELECT_ALL: MMC_NOTIFY_TYPE = 32778i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_EXPAND: MMC_NOTIFY_TYPE = 32779i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_HELP: MMC_NOTIFY_TYPE = 32780i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_MENU_BTNCLICK: MMC_NOTIFY_TYPE = 32781i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_MINIMIZED: MMC_NOTIFY_TYPE = 32782i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_PASTE: MMC_NOTIFY_TYPE = 32783i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_PROPERTY_CHANGE: MMC_NOTIFY_TYPE = 32784i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_QUERY_PASTE: MMC_NOTIFY_TYPE = 32785i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_REFRESH: MMC_NOTIFY_TYPE = 32786i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_REMOVE_CHILDREN: MMC_NOTIFY_TYPE = 32787i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_RENAME: MMC_NOTIFY_TYPE = 32788i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_SELECT: MMC_NOTIFY_TYPE = 32789i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_SHOW: MMC_NOTIFY_TYPE = 32790i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_VIEW_CHANGE: MMC_NOTIFY_TYPE = 32791i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_SNAPINHELP: MMC_NOTIFY_TYPE = 32792i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_CONTEXTHELP: MMC_NOTIFY_TYPE = 32793i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_INITOCX: MMC_NOTIFY_TYPE = 32794i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_FILTER_CHANGE: MMC_NOTIFY_TYPE = 32795i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_FILTERBTN_CLICK: MMC_NOTIFY_TYPE = 32796i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_RESTORE_VIEW: MMC_NOTIFY_TYPE = 32797i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_PRINT: MMC_NOTIFY_TYPE = 32798i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_PRELOAD: MMC_NOTIFY_TYPE = 32799i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_LISTPAD: MMC_NOTIFY_TYPE = 32800i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_EXPANDSYNC: MMC_NOTIFY_TYPE = 32801i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_COLUMNS_CHANGED: MMC_NOTIFY_TYPE = 32802i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMCN_CANPASTE_OUTOFPROC: MMC_NOTIFY_TYPE = 32803i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_PROPERTY_ACTION = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROPACT_DELETING: MMC_PROPERTY_ACTION = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROPACT_CHANGING: MMC_PROPERTY_ACTION = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_PROPACT_INITIALIZED: MMC_PROPERTY_ACTION = 3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_RESULT_VIEW_STYLE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_SINGLESEL: MMC_RESULT_VIEW_STYLE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_SHOWSELALWAYS: MMC_RESULT_VIEW_STYLE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_NOSORTHEADER: MMC_RESULT_VIEW_STYLE = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_ENSUREFOCUSVISIBLE: MMC_RESULT_VIEW_STYLE = 8i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_SCOPE_ITEM_STATE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_SCOPE_ITEM_STATE_NORMAL: MMC_SCOPE_ITEM_STATE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_SCOPE_ITEM_STATE_BOLD: MMC_SCOPE_ITEM_STATE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_SCOPE_ITEM_STATE_EXPANDEDONCE: MMC_SCOPE_ITEM_STATE = 3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_TASK_DISPLAY_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_TASK_DISPLAY_UNINITIALIZED: MMC_TASK_DISPLAY_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_TASK_DISPLAY_TYPE_SYMBOL: MMC_TASK_DISPLAY_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_TASK_DISPLAY_TYPE_VANILLA_GIF: MMC_TASK_DISPLAY_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_TASK_DISPLAY_TYPE_CHOCOLATE_GIF: MMC_TASK_DISPLAY_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_TASK_DISPLAY_TYPE_BITMAP: MMC_TASK_DISPLAY_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type MMC_VIEW_TYPE = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_TYPE_LIST: MMC_VIEW_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_TYPE_HTML: MMC_VIEW_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const MMC_VIEW_TYPE_OCX: MMC_VIEW_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type _ColumnSortOrder = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SortOrder_Ascending: _ColumnSortOrder = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const SortOrder_Descending: _ColumnSortOrder = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type _DocumentMode = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const DocumentMode_Author: _DocumentMode = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const DocumentMode_User: _DocumentMode = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const DocumentMode_User_MDI: _DocumentMode = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const DocumentMode_User_SDI: _DocumentMode = 3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type _ExportListOptions = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ExportListOptions_Default: _ExportListOptions = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ExportListOptions_Unicode: _ExportListOptions = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ExportListOptions_TabDelimited: _ExportListOptions = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ExportListOptions_SelectedItemsOnly: _ExportListOptions = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type _ListViewMode = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ListMode_Small_Icons: _ListViewMode = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ListMode_Large_Icons: _ListViewMode = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ListMode_List: _ListViewMode = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ListMode_Detail: _ListViewMode = 3i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ListMode_Filtered: _ListViewMode = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub type _ViewOptions = i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ViewOption_Default: _ViewOptions = 0i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ViewOption_ScopeTreeHidden: _ViewOptions = 1i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ViewOption_NoToolBars: _ViewOptions = 2i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ViewOption_NotPersistable: _ViewOptions = 4i32;
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub const ViewOption_ActionPaneHidden: _ViewOptions = 8i32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct CONTEXTMENUITEM {
    pub strName: ::windows_sys::core::PWSTR,
    pub strStatusBarText: ::windows_sys::core::PWSTR,
    pub lCommandID: i32,
    pub lInsertionPointID: i32,
    pub fFlags: i32,
    pub fSpecialFlags: i32,
}
impl ::core::marker::Copy for CONTEXTMENUITEM {}
impl ::core::clone::Clone for CONTEXTMENUITEM {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct CONTEXTMENUITEM2 {
    pub strName: ::windows_sys::core::PWSTR,
    pub strStatusBarText: ::windows_sys::core::PWSTR,
    pub lCommandID: i32,
    pub lInsertionPointID: i32,
    pub fFlags: i32,
    pub fSpecialFlags: i32,
    pub strLanguageIndependentName: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for CONTEXTMENUITEM2 {}
impl ::core::clone::Clone for CONTEXTMENUITEM2 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MENUBUTTONDATA {
    pub idCommand: i32,
    pub x: i32,
    pub y: i32,
}
impl ::core::marker::Copy for MENUBUTTONDATA {}
impl ::core::clone::Clone for MENUBUTTONDATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMCBUTTON {
    pub nBitmap: i32,
    pub idCommand: i32,
    pub fsState: u8,
    pub fsType: u8,
    pub lpButtonText: ::windows_sys::core::PWSTR,
    pub lpTooltipText: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for MMCBUTTON {}
impl ::core::clone::Clone for MMCBUTTON {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_COLUMN_DATA {
    pub nColIndex: i32,
    pub dwFlags: u32,
    pub nWidth: i32,
    pub ulReserved: usize,
}
impl ::core::marker::Copy for MMC_COLUMN_DATA {}
impl ::core::clone::Clone for MMC_COLUMN_DATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_COLUMN_SET_DATA {
    pub cbSize: i32,
    pub nNumCols: i32,
    pub pColData: *mut MMC_COLUMN_DATA,
}
impl ::core::marker::Copy for MMC_COLUMN_SET_DATA {}
impl ::core::clone::Clone for MMC_COLUMN_SET_DATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct MMC_EXPANDSYNC_STRUCT {
    pub bHandled: super::super::Foundation::BOOL,
    pub bExpanding: super::super::Foundation::BOOL,
    pub hItem: isize,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for MMC_EXPANDSYNC_STRUCT {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for MMC_EXPANDSYNC_STRUCT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct MMC_EXT_VIEW_DATA {
    pub viewID: ::windows_sys::core::GUID,
    pub pszURL: ::windows_sys::core::PCWSTR,
    pub pszViewTitle: ::windows_sys::core::PCWSTR,
    pub pszTooltipText: ::windows_sys::core::PCWSTR,
    pub bReplacesDefaultView: super::super::Foundation::BOOL,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for MMC_EXT_VIEW_DATA {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for MMC_EXT_VIEW_DATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_FILTERDATA {
    pub pszText: ::windows_sys::core::PWSTR,
    pub cchTextMax: i32,
    pub lValue: i32,
}
impl ::core::marker::Copy for MMC_FILTERDATA {}
impl ::core::clone::Clone for MMC_FILTERDATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_LISTPAD_INFO {
    pub szTitle: ::windows_sys::core::PWSTR,
    pub szButtonText: ::windows_sys::core::PWSTR,
    pub nCommandID: isize,
}
impl ::core::marker::Copy for MMC_LISTPAD_INFO {}
impl ::core::clone::Clone for MMC_LISTPAD_INFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_RESTORE_VIEW {
    pub dwSize: u32,
    pub cookie: isize,
    pub pViewType: ::windows_sys::core::PWSTR,
    pub lViewOptions: i32,
}
impl ::core::marker::Copy for MMC_RESTORE_VIEW {}
impl ::core::clone::Clone for MMC_RESTORE_VIEW {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct MMC_SNAPIN_PROPERTY {
    pub pszPropName: ::windows_sys::core::PCWSTR,
    pub varValue: super::Com::VARIANT,
    pub eAction: MMC_PROPERTY_ACTION,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for MMC_SNAPIN_PROPERTY {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for MMC_SNAPIN_PROPERTY {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_SORT_DATA {
    pub nColIndex: i32,
    pub dwSortOptions: u32,
    pub ulReserved: usize,
}
impl ::core::marker::Copy for MMC_SORT_DATA {}
impl ::core::clone::Clone for MMC_SORT_DATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_SORT_SET_DATA {
    pub cbSize: i32,
    pub nNumItems: i32,
    pub pSortData: *mut MMC_SORT_DATA,
}
impl ::core::marker::Copy for MMC_SORT_SET_DATA {}
impl ::core::clone::Clone for MMC_SORT_SET_DATA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_TASK {
    pub sDisplayObject: MMC_TASK_DISPLAY_OBJECT,
    pub szText: ::windows_sys::core::PWSTR,
    pub szHelpString: ::windows_sys::core::PWSTR,
    pub eActionType: MMC_ACTION_TYPE,
    pub Anonymous: MMC_TASK_0,
}
impl ::core::marker::Copy for MMC_TASK {}
impl ::core::clone::Clone for MMC_TASK {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub union MMC_TASK_0 {
    pub nCommandID: isize,
    pub szActionURL: ::windows_sys::core::PWSTR,
    pub szScript: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for MMC_TASK_0 {}
impl ::core::clone::Clone for MMC_TASK_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_TASK_DISPLAY_BITMAP {
    pub szMouseOverBitmap: ::windows_sys::core::PWSTR,
    pub szMouseOffBitmap: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for MMC_TASK_DISPLAY_BITMAP {}
impl ::core::clone::Clone for MMC_TASK_DISPLAY_BITMAP {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_TASK_DISPLAY_OBJECT {
    pub eDisplayType: MMC_TASK_DISPLAY_TYPE,
    pub Anonymous: MMC_TASK_DISPLAY_OBJECT_0,
}
impl ::core::marker::Copy for MMC_TASK_DISPLAY_OBJECT {}
impl ::core::clone::Clone for MMC_TASK_DISPLAY_OBJECT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub union MMC_TASK_DISPLAY_OBJECT_0 {
    pub uBitmap: MMC_TASK_DISPLAY_BITMAP,
    pub uSymbol: MMC_TASK_DISPLAY_SYMBOL,
}
impl ::core::marker::Copy for MMC_TASK_DISPLAY_OBJECT_0 {}
impl ::core::clone::Clone for MMC_TASK_DISPLAY_OBJECT_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_TASK_DISPLAY_SYMBOL {
    pub szFontFamilyName: ::windows_sys::core::PWSTR,
    pub szURLtoEOT: ::windows_sys::core::PWSTR,
    pub szSymbolString: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for MMC_TASK_DISPLAY_SYMBOL {}
impl ::core::clone::Clone for MMC_TASK_DISPLAY_SYMBOL {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct MMC_VISIBLE_COLUMNS {
    pub nVisibleColumns: i32,
    pub rgVisibleCols: [i32; 1],
}
impl ::core::marker::Copy for MMC_VISIBLE_COLUMNS {}
impl ::core::clone::Clone for MMC_VISIBLE_COLUMNS {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct RDCOMPARE {
    pub cbSize: u32,
    pub dwFlags: u32,
    pub nColumn: i32,
    pub lUserParam: super::super::Foundation::LPARAM,
    pub prdch1: *mut RDITEMHDR,
    pub prdch2: *mut RDITEMHDR,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for RDCOMPARE {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for RDCOMPARE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct RDITEMHDR {
    pub dwFlags: u32,
    pub cookie: isize,
    pub lpReserved: super::super::Foundation::LPARAM,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for RDITEMHDR {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for RDITEMHDR {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct RESULTDATAITEM {
    pub mask: u32,
    pub bScopeItem: super::super::Foundation::BOOL,
    pub itemID: isize,
    pub nIndex: i32,
    pub nCol: i32,
    pub str: ::windows_sys::core::PWSTR,
    pub nImage: i32,
    pub nState: u32,
    pub lParam: super::super::Foundation::LPARAM,
    pub iIndent: i32,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for RESULTDATAITEM {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for RESULTDATAITEM {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct RESULTFINDINFO {
    pub psz: ::windows_sys::core::PWSTR,
    pub nStart: i32,
    pub dwOptions: u32,
}
impl ::core::marker::Copy for RESULTFINDINFO {}
impl ::core::clone::Clone for RESULTFINDINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct RESULT_VIEW_TYPE_INFO {
    pub pstrPersistableViewDescription: ::windows_sys::core::PWSTR,
    pub eViewType: MMC_VIEW_TYPE,
    pub dwMiscOptions: u32,
    pub Anonymous: RESULT_VIEW_TYPE_INFO_0,
}
impl ::core::marker::Copy for RESULT_VIEW_TYPE_INFO {}
impl ::core::clone::Clone for RESULT_VIEW_TYPE_INFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub union RESULT_VIEW_TYPE_INFO_0 {
    pub dwListOptions: u32,
    pub Anonymous1: RESULT_VIEW_TYPE_INFO_0_0,
    pub Anonymous2: RESULT_VIEW_TYPE_INFO_0_1,
}
impl ::core::marker::Copy for RESULT_VIEW_TYPE_INFO_0 {}
impl ::core::clone::Clone for RESULT_VIEW_TYPE_INFO_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct RESULT_VIEW_TYPE_INFO_0_0 {
    pub dwHTMLOptions: u32,
    pub pstrURL: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for RESULT_VIEW_TYPE_INFO_0_0 {}
impl ::core::clone::Clone for RESULT_VIEW_TYPE_INFO_0_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct RESULT_VIEW_TYPE_INFO_0_1 {
    pub dwOCXOptions: u32,
    pub pUnkControl: ::windows_sys::core::IUnknown,
}
impl ::core::marker::Copy for RESULT_VIEW_TYPE_INFO_0_1 {}
impl ::core::clone::Clone for RESULT_VIEW_TYPE_INFO_0_1 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct SCOPEDATAITEM {
    pub mask: u32,
    pub displayname: ::windows_sys::core::PWSTR,
    pub nImage: i32,
    pub nOpenImage: i32,
    pub nState: u32,
    pub cChildren: i32,
    pub lParam: super::super::Foundation::LPARAM,
    pub relativeID: isize,
    pub ID: isize,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for SCOPEDATAITEM {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for SCOPEDATAITEM {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct SColumnSetID {
    pub dwFlags: u32,
    pub cBytes: u32,
    pub id: [u8; 1],
}
impl ::core::marker::Copy for SColumnSetID {}
impl ::core::clone::Clone for SColumnSetID {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`, `\"Win32_System_Com\"`*"]
#[cfg(feature = "Win32_System_Com")]
pub struct SMMCDataObjects {
    pub count: u32,
    pub lpDataObject: [super::Com::IDataObject; 1],
}
#[cfg(feature = "Win32_System_Com")]
impl ::core::marker::Copy for SMMCDataObjects {}
#[cfg(feature = "Win32_System_Com")]
impl ::core::clone::Clone for SMMCDataObjects {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct SMMCObjectTypes {
    pub count: u32,
    pub guid: [::windows_sys::core::GUID; 1],
}
impl ::core::marker::Copy for SMMCObjectTypes {}
impl ::core::clone::Clone for SMMCObjectTypes {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct SNodeID {
    pub cBytes: u32,
    pub id: [u8; 1],
}
impl ::core::marker::Copy for SNodeID {}
impl ::core::clone::Clone for SNodeID {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Mmc\"`*"]
pub struct SNodeID2 {
    pub dwFlags: u32,
    pub cBytes: u32,
    pub id: [u8; 1],
}
impl ::core::marker::Copy for SNodeID2 {}
impl ::core::clone::Clone for SNodeID2 {
    fn clone(&self) -> Self {
        *self
    }
}
