#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DevQuery_ObjectType: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x13673f42_a3d6_49f6_b4da_ae46e0c5237c), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_Characteristics: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 29u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_ClassCoInstallers: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x713d1703_a2e2_49f5_9214_56472ef3da5c), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_ClassInstaller: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_ClassName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_DHPRebalanceOptOut: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xd14d3ef3_66cf_4ba2_9d38_0ddb37ab4701), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_DefaultService: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 11u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_DevType: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 27u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_Exclusive: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 28u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_Icon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_IconPath: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 12u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_LowerFilters: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 20u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_Name: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_NoDisplayClass: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_NoInstallClass: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_NoUseClass: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_PropPageProvider: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_Security: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 25u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_SecuritySDS: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 26u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_SilentInstall: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x259abffc_50a7_47ce_af08_68c9a7d73366), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceClass_UpperFilters: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4321918b_f69e_470d_a5de_4d88c75ad24b), pid: 19u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Address: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 51u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_AlwaysShowDeviceAsConnected: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 101u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_AssociationArray: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 80u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_BaselineExperienceId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 78u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Category: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 90u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_CategoryGroup_Desc: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 94u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_CategoryGroup_Icon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 95u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Category_Desc_Plural: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 92u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Category_Desc_Singular: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 91u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Category_Icon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 93u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_ConfigFlags: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 105u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_CustomPrivilegedPackageFamilyNames: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 107u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_DeviceDescription1: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 81u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_DeviceDescription2: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 82u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_DeviceFunctionSubRank: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 100u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_DiscoveryMethod: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 52u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_ExperienceId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 89u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_FriendlyName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x656a3bb3_ecc0_43fd_8477_4ae0404a96cd), pid: 12288u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_HasProblem: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 83u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Icon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 57u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_InstallInProgress: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsAuthenticated: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 54u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsConnected: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 55u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsDefaultDevice: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 86u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsDeviceUniquelyIdentifiable: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 79u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsEncrypted: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 53u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsLocalMachine: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 70u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsMetadataSearchInProgress: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 72u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsNetworkDevice: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 85u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsNotInterestingForDisplay: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 74u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsPaired: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 56u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsRebootRequired: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 108u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsSharedDevice: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 84u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_IsShowInDisconnectedState: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 68u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Last_Connected: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 67u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Last_Seen: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 66u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_LaunchDeviceStageFromExplorer: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 77u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_LaunchDeviceStageOnDeviceConnect: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 76u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Manufacturer: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x656a3bb3_ecc0_43fd_8477_4ae0404a96cd), pid: 8192u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_MetadataCabinet: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 87u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_MetadataChecksum: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 73u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_MetadataPath: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 71u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_ModelName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x656a3bb3_ecc0_43fd_8477_4ae0404a96cd), pid: 8194u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_ModelNumber: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x656a3bb3_ecc0_43fd_8477_4ae0404a96cd), pid: 8195u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_PrimaryCategory: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 97u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_PrivilegedPackageFamilyNames: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 106u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_RequiresPairingElevation: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 88u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_RequiresUninstallElevation: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 99u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_UnpairUninstall: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 98u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceContainer_Version: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 65u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterfaceClass_DefaultInterface: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x14c83a99_0b3f_44b7_be4c_a178d3990564), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterfaceClass_Name: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x14c83a99_0b3f_44b7_be4c_a178d3990564), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_Autoplay_Silent: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x434dd28f_9e75_450a_9ab9_ff61e618bad0), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_ClassGuid: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_Enabled: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_FriendlyName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_ReferenceString: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_Restricted: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_SchematicName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DeviceInterface_UnrestrictedAppCapabilities: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x026e516e_b814_414b_83cd_856d6fef4822), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_AdditionalSoftwareRequested: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 19u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Address: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 30u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_AssignedToGuest: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 24u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BaseContainerId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 38u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BiosDeviceName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BusNumber: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 23u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BusRelations: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BusReportedDeviceDesc: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_BusTypeGuid: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 21u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Capabilities: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 17u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Characteristics: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 29u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Children: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Class: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ClassGuid: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_CompatibleIds: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ConfigFlags: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 12u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ConfigurationId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ContainerId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x8c7ed206_3f8a_4827_b3ab_ae9e1faefc6c), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_CreatorProcessId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 25u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DHP_Rebalance_Policy: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DebuggerSafe: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 12u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DependencyDependents: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 21u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DependencyProviders: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 20u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DevNodeStatus: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DevType: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 27u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DeviceDesc: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Driver: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 11u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverCoInstallers: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 11u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverDesc: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverInfPath: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverInfSection: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverInfSectionExt: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverLogoLevel: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 15u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverProblemDesc: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 11u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverPropPageProvider: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverProvider: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverRank: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 14u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_DriverVersion: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_EjectionRelations: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_EnumeratorName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 24u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Exclusive: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 28u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ExtendedAddress: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 23u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ExtendedConfigurationIds: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 15u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FirmwareDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 17u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FirmwareRevision: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 19u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FirmwareVersion: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 18u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FirstInstallDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 101u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FriendlyName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 14u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_FriendlyNameAttributes: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_GenericDriverInstalled: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 18u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_HardwareIds: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_HasProblem: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_InLocalMachineContainer: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x8c7ed206_3f8a_4827_b3ab_ae9e1faefc6c), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_InstallDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 100u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_InstallState: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 36u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_InstanceId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 256u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_IsAssociateableByUserAction: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_IsPresent: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_IsRebootRequired: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 16u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LastArrivalDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 102u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LastRemovalDate: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 103u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Legacy: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80497100_8c73_48b9_aad9_ce387e19c56e), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LegacyBusType: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 22u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LocationInfo: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 15u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LocationPaths: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 37u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_LowerFilters: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 20u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Manufacturer: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 13u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ManufacturerAttributes: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_MatchingDeviceId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Model: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x78c34fc8_104a_4aca_9ea4_524d52996e57), pid: 39u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ModelId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_NoConnectSound: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 17u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Numa_Node: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Numa_Proximity_Domain: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 1u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PDOName: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 16u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Parent: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PhysicalDeviceLocation: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 9u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PostInstallInProgress: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 13u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PowerData: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 32u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PowerRelations: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_PresenceNotForDevice: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ProblemCode: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ProblemStatus: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 12u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_RemovalPolicy: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 33u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_RemovalPolicyDefault: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 34u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_RemovalPolicyOverride: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 35u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_RemovalRelations: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Reported: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80497100_8c73_48b9_aad9_ce387e19c56e), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ReportedDeviceIdsHash: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ResourcePickerExceptions: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 13u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ResourcePickerTags: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa8b865dd_2e3d_4094_ad97_e593a70c75d6), pid: 12u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SafeRemovalRequired: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xafd97640_86a3_4210_b67c_289c41aabe55), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SafeRemovalRequiredOverride: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xafd97640_86a3_4210_b67c_289c41aabe55), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Security: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 25u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SecuritySDS: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 26u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Service: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SessionId: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x83da6326_97a6_4088_9453_a1923f573b29), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_ShowInUninstallUI: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 8u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Siblings: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SignalStrength: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x80d81ea6_7473_4b0c_8216_efc11a2c4c8b), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_SoftRestartSupported: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 22u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_Stack: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x540b947e_8b40_45bc_a8a2_6a0b894cbda2), pid: 14u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_TransportRelations: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0x4340a6c5_93fa_4706_972c_7b648008a5a7), pid: 11u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_UINumber: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 18u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_UINumberDescFormat: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 31u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_Device_UpperFilters: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xa45c254e_df1c_4efd_8020_67d146a850e0), pid: 19u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_BrandingIcon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 7u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_DetailedDescription: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 4u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_DocumentationLink: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 5u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_Icon: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 6u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_Model: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 2u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_DrvPkg_VendorWebSite: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xcf73bb51_3abf_44a2_85e0_9a3dc7a12132), pid: 3u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPKEY_NAME: DEVPROPKEY = DEVPROPKEY { fmtid: ::windows_sys::core::GUID::from_u128(0xb725f130_47ef_101a_a5f1_02608c9eebac), pid: 10u32 };
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROPID_FIRST_USABLE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_MASK_TYPE: u32 = 4095u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_MASK_TYPEMOD: u32 = 61440u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPEMOD_ARRAY: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPEMOD_LIST: u32 = 8192u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_BOOLEAN: u32 = 17u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_BYTE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_CURRENCY: u32 = 14u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_DATE: u32 = 15u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_DECIMAL: u32 = 12u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_DEVPROPKEY: u32 = 21u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_DEVPROPTYPE: u32 = 22u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_DOUBLE: u32 = 11u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_EMPTY: u32 = 0u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_ERROR: u32 = 23u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_FILETIME: u32 = 16u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_FLOAT: u32 = 10u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_GUID: u32 = 13u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_INT16: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_INT32: u32 = 6u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_INT64: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_NTSTATUS: u32 = 24u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_NULL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_SBYTE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_SECURITY_DESCRIPTOR: u32 = 19u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_SECURITY_DESCRIPTOR_STRING: u32 = 20u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_STRING: u32 = 18u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_STRING_INDIRECT: u32 = 25u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_UINT16: u32 = 5u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_UINT32: u32 = 7u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_TYPE_UINT64: u32 = 9u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const MAX_DEVPROP_TYPE: u32 = 25u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const MAX_DEVPROP_TYPEMOD: u32 = 8192u32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub type DEVPROPSTORE = i32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_STORE_SYSTEM: DEVPROPSTORE = 0i32;
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub const DEVPROP_STORE_USER: DEVPROPSTORE = 1i32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub struct DEVPROPCOMPKEY {
    pub Key: DEVPROPKEY,
    pub Store: DEVPROPSTORE,
    pub LocaleName: ::windows_sys::core::PCWSTR,
}
impl ::core::marker::Copy for DEVPROPCOMPKEY {}
impl ::core::clone::Clone for DEVPROPCOMPKEY {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub struct DEVPROPERTY {
    pub CompKey: DEVPROPCOMPKEY,
    pub Type: u32,
    pub BufferSize: u32,
    pub Buffer: *mut ::core::ffi::c_void,
}
impl ::core::marker::Copy for DEVPROPERTY {}
impl ::core::clone::Clone for DEVPROPERTY {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Devices_Properties\"`*"]
pub struct DEVPROPKEY {
    pub fmtid: ::windows_sys::core::GUID,
    pub pid: u32,
}
impl ::core::marker::Copy for DEVPROPKEY {}
impl ::core::clone::Clone for DEVPROPKEY {
    fn clone(&self) -> Self {
        *self
    }
}
